@@ -1,5 +1,5 @@
 from tkinter.ttk import Frame
-from .basecontainer import BaseContainer
+from . import BaseContainer
 
 class Container(BaseContainer, Frame):
    _DEFAULT_STYLE = BaseContainer._defaultStyle()
